==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/fi_FI.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Asetuksesi on päivitetty.",
"Activity" => "Toimet",
"A file or folder has been <strong>shared</strong>" => "Tiedosto tai kansio on <strong>jaettu</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Uusi tiedosto tai kansio on <strong>luotu</strong> jaettuun kansioon",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Tiedostoa tai kansiota on <strong>muutettu</strong> jaetussa kansiossa",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Tiedosto tai kansio on <strong>poistettu</strong> jaetusta kansiosta",
"You created %1\$s" => "Loit kohteen %1\$s",
"%2\$s created %1\$s" => "%2\$s loi kohteen %1\$s",
"You changed %1\$s" => "Muutit kohdetta %1\$s",
"%2\$s changed %1\$s" => "%2\$s muutti kohdetta %1\$s",
"You deleted %1\$s" => "Poistit kohteen %1\$s",
"%2\$s deleted %1\$s" => "%2\$s poisti kohteen %1\$s",
"You shared %1\$s with %2\$s" => "Jaoit kohteen %1\$s käyttäjän %2\$s kanssa",
"You shared %1\$s with group %2\$s" => "Jaoit kohteen %1\$s ryhmän %2\$s kanssa",
"%2\$s shared %1\$s with you" => "%2\$s jakoi kohteen %1\$s kanssasi",
"You shared %1\$s via link" => "Jaoit kohteen %1\$s linkin kautta",
"Activity notification" => "Ilmoitus toiminnasta",
"All Activities" => "Kaikki toimet",
"Activities by you" => "Omat toimet",
"Activities by others" => "Muiden toimet",
"Shares" => "Jaot",
"Files" => "Tiedostot",
"%s and %s" => "%s ja %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>","%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s ja %n lisää","%s ja %n lisää"),
"Hello %s," => "Hei %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän tunnin aikana.",
"You are receiving this email because in the last day the following things happened at %s" => "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän vuorokauden aikana.",
"You are receiving this email because in the last week the following things happened at %s" => "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viime viikon aikana.",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Näet tapahtumaluettelon täällä, kun aloitat %sin käytön.",
"No more events to load" => "Ei enempää tapahtumia ladattavaksi",
"Enable RSS feed" => "Käytä RSS-syötettä",
"Notifications" => "Ilmoitukset",
"You need to set up your email address before you can receive notification emails." => "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
"Send emails:" => "Lähetä sähköpostit:",
"Hourly" => "Tunneittain",
"Daily" => "Päivittäin",
"Weekly" => "Viikottain",
"Activity feed" => "Toiminnan syöte",
"Personal activity feed for %s" => "Käyttäjän %s henkilökohtainen toimintasyöte"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/fi_FI.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Asetuksesi on päivitetty.",
"Activity" => "Toimet",
"A file or folder has been <strong>shared</strong>" => "Tiedosto tai kansio on <strong>jaettu</strong>",
"A new file or folder has been <strong>created</strong>" => "Uusi tiedosto tai kansio on <strong>luotu</strong>",
"A file or folder has been <strong>changed</strong>" => "Tiedostoa tai kansiota on <strong>muutettu</strong>",
"A file or folder has been <strong>deleted</strong>" => "Tiedosto tai kansio on <strong>poistettu</strong>",
"You created %1\$s" => "Loit kohteen %1\$s",
"%2\$s created %1\$s" => "%2\$s loi kohteen %1\$s",
"You changed %1\$s" => "Muutit kohdetta %1\$s",
"%2\$s changed %1\$s" => "%2\$s muutti kohdetta %1\$s",
"You deleted %1\$s" => "Poistit kohteen %1\$s",
"%2\$s deleted %1\$s" => "%2\$s poisti kohteen %1\$s",
"You shared %1\$s with %2\$s" => "Jaoit kohteen %1\$s käyttäjän %2\$s kanssa",
"You shared %1\$s with group %2\$s" => "Jaoit kohteen %1\$s ryhmän %2\$s kanssa",
"%2\$s shared %1\$s with you" => "%2\$s jakoi kohteen %1\$s kanssasi",
"You shared %1\$s via link" => "Jaoit kohteen %1\$s linkin kautta",
"Activity notification" => "Ilmoitus toiminnasta",
"All Activities" => "Kaikki toimet",
"Activities by you" => "Omat toimet",
"Activities by others" => "Muiden toimet",
"Shares" => "Jaot",
"Files" => "Tiedostot",
"%s and %s" => "%s ja %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>","%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s ja %n lisää","%s ja %n lisää"),
"Hello %s," => "Hei %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän tunnin aikana.",
"You are receiving this email because in the last day the following things happened at %s" => "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän vuorokauden aikana.",
"You are receiving this email because in the last week the following things happened at %s" => "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viime viikon aikana.",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Näet tapahtumaluettelon täällä, kun aloitat %sin käytön.",
"No more events to load" => "Ei enempää tapahtumia ladattavaksi",
"Enable RSS feed" => "Käytä RSS-syötettä",
"Notifications" => "Ilmoitukset",
"Mail" => "Sähköposti",
"Notify about my own actions" => "Ilmoita omista toimistani",
"You need to set up your email address before you can receive notification emails." => "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
"Send emails:" => "Lähetä sähköpostit:",
"Hourly" => "Tunneittain",
"Daily" => "Päivittäin",
"Weekly" => "Viikottain",
"Activity feed" => "Toiminnan syöte",
"Personal activity feed for %s" => "Käyttäjän %s henkilökohtainen toimintasyöte"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
